@@ -2,9 +2,7 @@
 //
 // Abstract a Rivendell Netcatch Recording.
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdrecording.cpp,v 1.24.2.1 2008/11/14 21:30:53 fredg Exp $
+//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -22,6 +20,8 @@
 
 #include <unistd.h>
 
+#include <qobject.h>
+
 #include <rd.h>
 #include <rdconf.h>
 #include <rddb.h>
@@ -400,13 +400,13 @@ void RDRecording::setChannels(int chan) const
 }
 
 
-int RDRecording::samprate() const
+int RDRecording::sampleRate() const
 {
   return GetIntValue("SAMPRATE");
 }
 
 
-void RDRecording::setSamprate(int rate) const
+void RDRecording::setSampleRate(int rate)
 {
   SetRow("SAMPRATE",rate);
 }
@@ -616,6 +616,18 @@ void RDRecording::setUrlPassword(QString passwd) const
 }
 
 
+bool RDRecording::enableMetadata() const
+{
+  return GetBoolValue("ENABLE_METADATA");
+}
+
+
+void RDRecording::setEnableMetadata(bool state) const
+{
+  SetRow("ENABLE_METADATA",state);
+}
+
+
 int RDRecording::feedId() const
 {
   return GetIntValue("FEED_ID");
@@ -663,27 +675,27 @@ QString RDRecording::typeString(RDRecording::Type type)
 
   switch(type) {
       case RDRecording::Recording:
-	str=QT_TR_NOOP("Recording");
+	str=QObject::tr("Recording");
 	break;
 
       case RDRecording::MacroEvent:
-	str=QT_TR_NOOP("Macro Event");
+	str=QObject::tr("Macro Event");
 	break;
 
       case RDRecording::SwitchEvent:
-	str=QT_TR_NOOP("Switch Event");
+	str=QObject::tr("Switch Event");
 	break;
 
       case RDRecording::Playout:
-	str=QT_TR_NOOP("Playout");
+	str=QObject::tr("Playout");
 	break;
 
       case RDRecording::Download:
-	str=QT_TR_NOOP("Download");
+	str=QObject::tr("Download");
 	break;
 
       case RDRecording::Upload:
-	str=QT_TR_NOOP("Upload");
+	str=QObject::tr("Upload");
 	break;
   }
 
@@ -691,6 +703,75 @@ QString RDRecording::typeString(RDRecording::Type type)
 }
 
 
+QString RDRecording::exitString(RDRecording::ExitCode code)
+{
+  QString ret;
+
+  switch(code) {
+      case RDRecording::Ok:
+	ret=QObject::tr("Ok");
+	break;
+
+      case RDRecording::Short:
+	ret=QObject::tr("Short Length");
+	break;
+
+      case RDRecording::LowLevel:
+	ret=QObject::tr("Low Level");
+	break;
+
+      case RDRecording::HighLevel:
+	ret=QObject::tr("High Level");
+	break;
+
+      case RDRecording::Downloading:
+	ret=QObject::tr("Downloading");
+	break;
+
+      case RDRecording::Uploading:
+	ret=QObject::tr("Uploading");
+	break;
+
+      case RDRecording::ServerError:
+	ret=QObject::tr("Server Error");
+	break;
+
+      case RDRecording::InternalError:
+	ret=QObject::tr("Internal Error");
+	break;
+
+      case RDRecording::Interrupted:
+	ret=QObject::tr("Interrupted");
+	break;
+
+      case RDRecording::RecordActive:
+	ret=QObject::tr("Recording");
+	break;
+
+      case RDRecording::PlayActive:
+	ret=QObject::tr("Playing");
+	break;
+
+      case RDRecording::Waiting:
+	ret=QObject::tr("Waiting");
+	break;
+
+      case RDRecording::DeviceBusy:
+	ret=QObject::tr("Device Busy");
+	break;
+
+      case RDRecording::NoCut:
+	ret=QObject::tr("No Such Cart/Cut");
+	break;
+
+      case RDRecording::UnknownFormat:
+	ret=QObject::tr("Unknown Audio Format");
+	break;
+  }
+  return ret;
+}
+
+
 int RDRecording::GetIntValue(QString field) const
 {
   QString sql;
