@@ -2,9 +2,7 @@
 //
 // Abstract a Rivendell Report Descriptor
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdreport.cpp,v 1.27.4.8.2.4 2014/06/24 18:27:05 cvs Exp $
+//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,6 +18,8 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#include <stdlib.h>
+
 #include <qfile.h>
 #include <qobject.h>
 
@@ -32,7 +32,7 @@
 #include <rdescape_string.h>
 #include <rddatedecode.h>
 
-RDReport::RDReport(const QString &rptname,QObject *parent,const char *name)
+RDReport::RDReport(const QString &rptname,QObject *parent)
 {
   report_name=rptname;
   report_error_code=RDReport::ErrorOk;
@@ -87,14 +87,27 @@ void RDReport::setFilter(ExportFilter filter) const
 
 QString RDReport::exportPath(ExportOs ostype) const
 {
-  return RDGetSqlValue("REPORTS","NAME",report_name,OsFieldName(ostype)).
-    toString();
+  return RDGetSqlValue("REPORTS","NAME",report_name,
+		       OsFieldName(ostype)+"EXPORT_PATH").toString();
 }
 
 
 void RDReport::setExportPath(ExportOs ostype,const QString &path) const
 {
-  SetRow(OsFieldName(ostype),path);
+  SetRow(OsFieldName(ostype)+"EXPORT_PATH",path);
+}
+
+
+QString RDReport::postExportCommand(ExportOs ostype) const
+{
+  return RDGetSqlValue("REPORTS","NAME",report_name,
+		       OsFieldName(ostype)+"POST_EXPORT_CMD").toString();
+}
+
+
+void RDReport::setPostExportCommand(ExportOs ostype,const QString &cmd) const
+{
+  SetRow(OsFieldName(ostype)+"POST_EXPORT_CMD",cmd);
 }
 
 
@@ -415,14 +428,20 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
   //
   // Generate Mixdown Table
   //
+  // Create Table
+  //
   QString mixname="MIXDOWN"+station->name();
-  sql=QString().sprintf("drop table `%s_SRT`",(const char *)mixname);
+  sql=QString("drop table `")+mixname+"_SRT`";
   QSqlQuery *p;
   p=new QSqlQuery(sql);
   delete p;
-  sql=RDCreateReconciliationTableSql(mixname);
+  sql=RDCreateReconciliationTableSql(mixname+"_SRT");
   q=new RDSqlQuery(sql);
   delete q;
+
+  //
+  // Iterate Selected Services
+  //
   sql=QString().sprintf("select SERVICE_NAME from REPORT_SERVICES \
                          where REPORT_NAME=\"%s\"",
 			(const char *)name());
@@ -432,51 +451,77 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
     if(svc->exists()) {
       rec_name=q->value(0).toString();
       rec_name.replace(" ","_");
+
+      //
+      // Generate Type Filters
+      //
       force_sql="";
-      if(exportTypeForced(RDReport::Traffic)) {
-	force_sql+=QString().sprintf("(`%s_SRT`.EVENT_SOURCE=%d)||",
+      if(!exportTypeEnabled(RDReport::Generic)) {
+	if(exportTypeForced(RDReport::Traffic)||
+	   exportTypeEnabled(RDReport::Traffic)) {
+	  force_sql+=QString().sprintf("(`%s_SRT`.EVENT_SOURCE=%d)||",
 				       (const char *)rec_name,
 				       RDLogLine::Traffic);
-      }
-      if(exportTypeForced(RDReport::Music)) {
-	force_sql+=QString().sprintf("(`%s_SRT`.EVENT_SOURCE=%d)||",
+	}
+	if(exportTypeForced(RDReport::Music)||
+	   exportTypeEnabled(RDReport::Music)) {
+	  force_sql+=QString().sprintf("(`%s_SRT`.EVENT_SOURCE=%d)||",
 				       (const char *)rec_name,
 				       RDLogLine::Music);
+	}
+	force_sql=force_sql.left(force_sql.length()-2);
       }
-      force_sql=force_sql.left(force_sql.length()-2);
 
-      sql=QString().sprintf("select LENGTH,LOG_ID,CART_NUMBER,STATION_NAME,\
-                           EVENT_DATETIME,EVENT_TYPE,EXT_START_TIME,\
-                           EXT_LENGTH,EXT_DATA,EXT_EVENT_ID,EXT_ANNC_TYPE,\
-                           PLAY_SOURCE,CUT_NUMBER,EVENT_SOURCE,EXT_CART_NAME,\
-                           LOG_NAME,`%s_SRT`.TITLE,`%s_SRT`.ARTIST,\
-                           SCHEDULED_TIME,\
-                           START_SOURCE,`%s_SRT`.PUBLISHER,`%s_SRT`.COMPOSER,\
-                           `%s_SRT`.ALBUM,`%s_SRT`.LABEL,\
-                           `%s_SRT`.ISRC,`%s_SRT`.USAGE_CODE,\
-                           `%s_SRT`.ONAIR_FLAG,`%s_SRT`.ISCI,\
-                           `%s_SRT`.CONDUCTOR,`%s_SRT`.USER_DEFINED,\
-                           `%s_SRT`.SONG_ID from `%s_SRT`\
-                           left join CART on `%s_SRT`.CART_NUMBER=CART.NUMBER \
-                           where ",
-			    (const char *)rec_name,
-			    (const char *)rec_name,
-			    (const char *)rec_name,
-			    (const char *)rec_name,
-			    (const char *)rec_name,
-			    (const char *)rec_name,
-			    (const char *)rec_name,
-			    (const char *)rec_name,
-			    (const char *)rec_name,
-			    (const char *)rec_name,
-			    (const char *)rec_name,
-			    (const char *)rec_name,
-			    (const char *)rec_name,
-			    (const char *)rec_name,
-			    (const char *)rec_name);
+      //
+      // Selected Fields
+      //
+      sql=QString("select ")+
+	"LENGTH,"+                           // 00
+	"LOG_ID,"+                           // 01
+	"CART_NUMBER,"+                      // 02
+	"STATION_NAME,"+                     // 03
+	"EVENT_DATETIME,"+                   // 04
+	"EVENT_TYPE,"+                       // 05
+	"EXT_START_TIME,"+                   // 06
+	"EXT_LENGTH,"+                       // 07
+	"EXT_DATA,"+                         // 08
+	"EXT_EVENT_ID,"+                     // 09
+	"EXT_ANNC_TYPE,"+                    // 10
+	"PLAY_SOURCE,"+                      // 11
+	"CUT_NUMBER,"+                       // 12
+	"EVENT_SOURCE,"+                     // 13
+	"EXT_CART_NAME,"+                    // 14
+	"LOG_NAME,"+                         // 15
+	"`"+rec_name+"_SRT`.TITLE,"+         // 16
+	"`"+rec_name+"_SRT`.ARTIST,"+        // 17
+	"SCHEDULED_TIME,"+                   // 18
+	"START_SOURCE,"+                     // 19
+	"`"+rec_name+"_SRT`.PUBLISHER,"+     // 20
+	"`"+rec_name+"_SRT`.COMPOSER,"+      // 21
+	"`"+rec_name+"_SRT`.ALBUM,"+         // 22
+	"`"+rec_name+"_SRT`.LABEL,"+         // 23
+	"`"+rec_name+"_SRT`.ISRC,"+          // 24
+	"`"+rec_name+"_SRT`.USAGE_CODE,"+    // 25
+	"`"+rec_name+"_SRT`.ONAIR_FLAG,"+    // 26
+	"`"+rec_name+"_SRT`.ISCI,"+          // 27
+	"`"+rec_name+"_SRT`.CONDUCTOR,"+     // 28
+	"`"+rec_name+"_SRT`.USER_DEFINED,"+  // 29
+	"`"+rec_name+"_SRT`.SONG_ID,"+       // 30
+	"`"+rec_name+"_SRT`.DESCRIPTION,"+   // 31
+	"`"+rec_name+"_SRT`.OUTCUE "+        // 32
+	"from `"+rec_name+"_SRT` left join CART "+
+	"on `"+rec_name+"_SRT`.CART_NUMBER=CART.NUMBER where ";
+
+      //
+      // OnAir Flag Filter
+      //
       if(filterOnairFlag()) {
 	sql+="(ONAIR_FLAG=\"Y\")&&";
       }
+
+      //
+      // Group Filter
+      //
       sql+="(";
       if(!group_sql.isEmpty()) {
 	sql+=QString("(")+group_sql+")&&";
@@ -484,6 +529,10 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
       if(!force_sql.isEmpty()) {
 	sql+=QString("(")+force_sql+")&&";
       }
+
+      //
+      // Daypart Filter
+      //
       if(daypart_sql.isEmpty()) {
 	sql+=QString("(EVENT_DATETIME>=\"")+startdate.toString("yyyy-MM-dd")+
 	  " 00:00:00\")&&"+
@@ -498,7 +547,6 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
       }
       sql=sql.left(sql.length()-2);
       sql+=")";
-      //printf("SQL: %s\n",(const char *)sql);
       q1=new RDSqlQuery(sql);
       while(q1->next()) {
 	sql=QString("insert into `")+mixname+"_SRT` "+
@@ -536,7 +584,9 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
 	  "ISCI=\""+RDEscapeString(q1->value(27).toString())+"\","+
 	  "CONDUCTOR=\""+RDEscapeString(q1->value(28).toString())+"\","+
 	  "USER_DEFINED=\""+RDEscapeString(q1->value(29).toString())+"\","+
-	  "SONG_ID=\""+RDEscapeString(q1->value(30).toString())+"\"";
+	  "SONG_ID=\""+RDEscapeString(q1->value(30).toString())+"\","+
+	  "DESCRIPTION=\""+RDEscapeString(q1->value(31).toString())+"\","+
+	  "OUTCUE=\""+RDEscapeString(q1->value(32).toString())+"\"";
 	q2=new RDSqlQuery(sql);
 	delete q2;
       }
@@ -548,73 +598,89 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
 
   bool ret=false;
   switch(filter()) {
-      case RDReport::CbsiDeltaFlex:
-	ret=ExportDeltaflex(startdate,enddate,mixname);
-	break;
+  case RDReport::CbsiDeltaFlex:
+    ret=ExportDeltaflex(startdate,enddate,mixname);
+    break;
 
-      case RDReport::TextLog:
-	ret=ExportTextLog(startdate,enddate,mixname);
-	break;
+  case RDReport::TextLog:
+    ret=ExportTextLog(startdate,enddate,mixname);
+    break;
 
-      case RDReport::BmiEmr:
-	ret=ExportBmiEmr(startdate,enddate,mixname);
-	break;
+  case RDReport::BmiEmr:
+    ret=ExportBmiEmr(startdate,enddate,mixname);
+    break;
 
-      case RDReport::NaturalLog:
-      case RDReport::Technical:
-	ret=ExportTechnical(startdate,enddate,mixname);
-	break;
+  case RDReport::NaturalLog:
+  case RDReport::Technical:
+    ret=ExportTechnical(startdate,enddate,true,false,mixname);
+    break;
 
-      case RDReport::SoundExchange:
-	ret=ExportSoundEx(startdate,enddate,mixname);
-	break;
+  case RDReport::SoundExchange:
+    ret=ExportSoundEx(startdate,enddate,mixname);
+    break;
 
-      case RDReport::NprSoundExchange:
-	ret=ExportNprSoundEx(startdate,enddate,mixname);
-	break;
+  case RDReport::NprSoundExchange:
+    ret=ExportNprSoundEx(startdate,enddate,mixname);
+    break;
 
-      case RDReport::RadioTraffic:
-	ret=ExportRadioTraffic(startdate,enddate,mixname);
-	break;
+  case RDReport::RadioTraffic:
+    ret=ExportRadioTraffic(startdate,enddate,mixname);
+    break;
 
-      case RDReport::VisualTraffic:
-	ret=ExportDeltaflex(startdate,enddate,mixname);
-	break;
+  case RDReport::VisualTraffic:
+    ret=ExportDeltaflex(startdate,enddate,mixname);
+    break;
 
-      case RDReport::CounterPoint:
-      case RDReport::WideOrbit:
-	ret=ExportRadioTraffic(startdate,enddate,mixname);
-	break;
+  case RDReport::CounterPoint:
+  case RDReport::WideOrbit:
+    ret=ExportRadioTraffic(startdate,enddate,mixname);
+    break;
 
-      case RDReport::Music1:
-	ret=ExportRadioTraffic(startdate,enddate,mixname);
-	break;
+  case RDReport::Music1:
+    ret=ExportRadioTraffic(startdate,enddate,mixname);
+    break;
 
-      case RDReport::MusicClassical:
-	ret=ExportMusicClassical(startdate,enddate,mixname);
-	break;
+  case RDReport::MusicClassical:
+    ret=ExportMusicClassical(startdate,enddate,mixname);
+    break;
 
-      case RDReport::MusicPlayout:
-	ret=ExportMusicPlayout(startdate,enddate,mixname);
-	break;
+  case RDReport::MusicPlayout:
+    ret=ExportMusicPlayout(startdate,enddate,mixname);
+    break;
 
-      case RDReport::MusicSummary:
-	ret=ExportMusicSummary(startdate,enddate,mixname);
-	break;
+  case RDReport::SpinCount:
+    ret=ExportSpinCount(startdate,enddate,mixname);
+    break;
 
-      default:
-	return false;
-	break;
+  case RDReport::MusicSummary:
+    ret=ExportMusicSummary(startdate,enddate,mixname);
+    break;
+
+  case RDReport::MrMaster:
+    ret=ExportTechnical(startdate,enddate,false,true,mixname);
+    break;
+
+  case RDReport::CutLog:
+    ret=ExportCutLog(startdate,enddate,mixname);
+    break;
+
+  default:
+    return false;
+    break;
   }
 #ifdef WIN32
   *out_path=RDDateDecode(exportPath(RDReport::Windows),startdate);
+  QString post_cmd=RDDateDecode(postExportCommand(RDReport::Windows),startdate);
 #else
   *out_path=RDDateDecode(exportPath(RDReport::Linux),startdate);
+  QString post_cmd=RDDateDecode(postExportCommand(RDReport::Linux),startdate);
 #endif
+  system(post_cmd);
   //  printf("MIXDOWN TABLE: %s_SRT\n",(const char *)mixname);
   sql=QString().sprintf("drop table `%s_SRT`",(const char *)mixname);
   q=new RDSqlQuery(sql);
   delete q;
+
   return ret;
 }
 
@@ -649,6 +715,9 @@ QString RDReport::filterText(RDReport::ExportFilter filter)
   case RDReport::CounterPoint:
     return QObject::tr("CounterPoint Traffic Reconciliation");
 
+  case RDReport::MrMaster:
+    return QObject::tr("Mr. Master Reconciliation");
+
   case RDReport::Music1:
     return QObject::tr("Music1 Reconciliation");
 
@@ -664,9 +733,15 @@ QString RDReport::filterText(RDReport::ExportFilter filter)
   case RDReport::NaturalLog:
     return QObject::tr("NaturalLog Reconciliation");
 
+  case RDReport::SpinCount:
+    return QObject::tr("Spin Count");
+
   case RDReport::WideOrbit:
     return QObject::tr("WideOrbit Traffic Reconciliation");
 
+  case RDReport::CutLog:
+    return QObject::tr("Cut Log");
+
   default:
     return QObject::tr("Unknown");
   }
@@ -702,11 +777,14 @@ bool RDReport::multipleDaysAllowed(RDReport::ExportFilter filter)
   case RDReport::VisualTraffic:
   case RDReport::CounterPoint:
   case RDReport::LastFilter:
+  case RDReport::MrMaster:
   case RDReport::Music1:
   case RDReport::MusicClassical:
   case RDReport::MusicPlayout:
   case RDReport::NaturalLog:
+  case RDReport::SpinCount:
   case RDReport::WideOrbit:
+  case RDReport::CutLog:
     return false;
 
   case RDReport::BmiEmr:
@@ -730,16 +808,19 @@ bool RDReport::multipleMonthsAllowed(RDReport::ExportFilter filter)
   case RDReport::VisualTraffic:
   case RDReport::CounterPoint:
   case RDReport::LastFilter:
+  case RDReport::MrMaster:
   case RDReport::Music1:
   case RDReport::MusicClassical:
   case RDReport::MusicPlayout:
   case RDReport::NaturalLog:
   case RDReport::WideOrbit:
+  case RDReport::CutLog:
     return false;
     
   case RDReport::MusicSummary:
   case RDReport::NprSoundExchange:
   case RDReport::SoundExchange:
+  case RDReport::SpinCount:
   case RDReport::Technical:
     return true;
   }
@@ -865,10 +946,10 @@ QString RDReport::OsFieldName(ExportOs os) const
 {
   switch(os) {
       case RDReport::Linux:
-	return QString("EXPORT_PATH");
+	return QString("");
 	
       case RDReport::Windows:
-	return QString("WIN_EXPORT_PATH");
+	return QString("WIN_");
   }
   return QString();
 }
