@@ -2,9 +2,7 @@
 //
 //   A Container Class for Audio Meta Data.
 //
-//   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
-//
-//    $Id: rdwavedata.h,v 1.5.8.3.2.1 2014/05/28 21:21:41 cvs Exp $
+//   (C) Copyright 2002-2006,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU Library General Public License 
@@ -19,7 +17,6 @@
 //   License along with this program; if not, write to the Free Software
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-//
 
 #ifndef RDWAVEDATA_H
 #define RDWAVEDATA_H
@@ -129,6 +126,10 @@ class RDWaveData
   void setEndDate(const QDate &date);
   QTime endTime() const;
   void setEndTime(const QTime &time);
+  QTime daypartStartTime() const;
+  void setDaypartStartTime(const QTime &time);
+  QTime daypartEndTime() const;
+  void setDaypartEndTime(const QTime &time);
   void clear();
 
  private:
@@ -185,6 +186,8 @@ class RDWaveData
   QTime data_start_time;
   QDate data_end_date;
   QTime data_end_time;
+  QTime data_daypart_start_time;
+  QTime data_daypart_end_time;
 };
 
 
