@@ -2,9 +2,7 @@
 //
 // Add a Rivendell Workstation
 //
-//   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: add_station.cpp,v 1.32.6.1 2013/03/09 00:21:11 cvs Exp $
+//   (C) Copyright 2002-2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -41,9 +39,8 @@
 #include <rdpasswd.h>
 #include <rdtextvalidator.h>
 
-
-AddStation::AddStation(QString *stationname,QWidget *parent,const char *name)
-  : QDialog(parent,name,true)
+AddStation::AddStation(QString *stationname,QWidget *parent)
+  : QDialog(parent,"",true)
 {
   add_name=stationname;
 
@@ -66,16 +63,16 @@ AddStation::AddStation(QString *stationname,QWidget *parent,const char *name)
   //
   // Text Validator
   //
-  RDTextValidator *validator=new RDTextValidator(this,"validator");
+  RDTextValidator *validator=new RDTextValidator(this);
 
   //
   // Station Name
   //
-  add_name_edit=new QLineEdit(this,"add_name_edit");
+  add_name_edit=new QLineEdit(this);
   add_name_edit->setGeometry(130,10,sizeHint().width()-140,19);
   add_name_edit->setMaxLength(64);
   add_name_edit->setValidator(validator);
-  QLabel *label=new QLabel(add_name_edit,tr("New &Host Name:"),this,"label");
+  QLabel *label=new QLabel(add_name_edit,tr("New &Host Name:"),this);
   label->setGeometry(10,10,115,19);
   label->setFont(font);
   label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
@@ -83,9 +80,9 @@ AddStation::AddStation(QString *stationname,QWidget *parent,const char *name)
   //
   // Exemplar
   //
-  add_exemplar_box=new QComboBox(this,"add_exemplar_box");
+  add_exemplar_box=new QComboBox(this);
   add_exemplar_box->setGeometry(130,35,sizeHint().width()-140,19);
-  label=new QLabel(add_exemplar_box,tr("Base Host On:"),this,"label");
+  label=new QLabel(add_exemplar_box,tr("Base Host On:"),this);
   label->setGeometry(10,35,115,19);
   label->setFont(font);
   label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
@@ -93,7 +90,7 @@ AddStation::AddStation(QString *stationname,QWidget *parent,const char *name)
   //
   //  Ok Button
   //
-  QPushButton *ok_button=new QPushButton(this,"ok_button");
+  QPushButton *ok_button=new QPushButton(this);
   ok_button->setGeometry(sizeHint().width()-180,sizeHint().height()-60,
 			 80,50);
   ok_button->setDefault(true);
@@ -104,7 +101,7 @@ AddStation::AddStation(QString *stationname,QWidget *parent,const char *name)
   //
   //  Cancel Button
   //
-  QPushButton *cancel_button=new QPushButton(this,"cancel_button");
+  QPushButton *cancel_button=new QPushButton(this);
   cancel_button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,
 			     80,50);
   cancel_button->setFont(font);
@@ -200,6 +197,16 @@ void AddStation::okData()
       q=new RDSqlQuery(sql);
       delete q;
     }
+    for(unsigned i=0;i<RD_CUT_EVENT_ID_QUAN;i++) {
+      for(unsigned j=0;j<MAX_DECKS;j++) {
+	sql=QString("insert into DECK_EVENTS set ")+
+	  "STATION_NAME=\""+RDEscapeString(add_name_edit->text())+"\","+
+	  QString().sprintf("CHANNEL=%u,",j+129)+
+	  QString().sprintf("NUMBER=%u",i+1);
+	q=new RDSqlQuery(sql);
+	delete q;
+      }
+    }
   }
   else {    // Use Specified Config
 
@@ -411,6 +418,24 @@ void AddStation::okData()
       delete q1;
     }
     delete q;
+ 
+    //
+    // Clone Deck Events
+    //
+    sql=QString("select CHANNEL,NUMBER,CART_NUMBER from DECK_EVENTS ")+
+      "where STATION_NAME=\""+RDEscapeString(add_exemplar_box->currentText())+
+      "\"";
+    q=new RDSqlQuery(sql);
+    while(q->next()) {
+      sql=QString("insert into DECK_EVENTS set ")+
+	"STATION_NAME=\""+RDEscapeString(add_name_edit->text())+"\","+
+	QString().sprintf("CHANNEL=%u,",q->value(0).toUInt())+
+	QString().sprintf("NUMBER=%d,",q->value(1).toInt())+
+	QString().sprintf("CART_NUMBER=%u",q->value(2).toUInt());
+      q1=new RDSqlQuery(sql);
+      delete q1;
+    }
+    delete q;
 
     //
     // Clone RDAirPlay Config
@@ -912,7 +937,7 @@ void AddStation::okData()
   }
   *add_name=add_name_edit->text();
 
-  EditStation *station=new EditStation(add_name_edit->text(),this,"station");
+  EditStation *station=new EditStation(add_name_edit->text(),this);
   int res=station->exec();
   delete station;
 
