@@ -2,9 +2,7 @@
 //
 // The On Air Playout Utility for Rivendell.
 //
-//   (C) Copyright 2002-2010 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdairplay.cpp,v 1.189.2.13 2013/03/22 15:11:51 cvs Exp $
+//   (C) Copyright 2002-2010,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -29,6 +27,7 @@
 #include <syslog.h>
 
 #include <qapplication.h>
+#include <qwindowsstyle.h>
 #include <qwidget.h>
 #include <qpainter.h>
 #include <qsqlpropertymap.h>
@@ -76,7 +75,6 @@ RDAirPlayConf *rdairplay_conf;
 RDAudioPort *rdaudioport_conf;
 RDUser *rduser;
 RDRipc *rdripc;
-RDCae *rdcae;
 RDEventPlayer *rdevent_player;
 RDCartDialog *rdcart_dialog;
 RDConfig *air_config;
@@ -100,8 +98,8 @@ void MainWidget::logLine(RDConfig::LogPriority prio,const QString &s)
   LogLine(prio,s);
 }
 
-MainWidget::MainWidget(QWidget *parent,const char *name)
-  :QWidget(parent,name)
+MainWidget::MainWidget(QWidget *parent)
+  :QWidget(parent)
 {
   prog_ptr=this;
   QString str;
@@ -133,7 +131,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   air_splash_screen=new QSplashScreen(QPixmap(rivendell_128x128_xpm));
   air_splash_screen->hide();
-  QTimer *timer=new QTimer(this,"splash_timer");
+  QTimer *timer=new QTimer(this);
   connect(timer,SIGNAL(timeout()),this,SLOT(clearSplashData()));
   timer->start(AIR_PLAY_SPLASH_TIME,true);
 
@@ -211,7 +209,6 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   air_rivendell_map=new QPixmap(rivendell_xpm);
   setIcon(*air_rivendell_map);
 
-  air_op_mode=RDAirPlayConf::Previous;
   air_start_next=false;
   air_next_button=0;
 
@@ -255,7 +252,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Master Clock Timer
   //
-  air_master_timer=new QTimer(this,"air_master_timer");
+  air_master_timer=new QTimer(this);
   connect(air_master_timer,SIGNAL(timeout()),this,SLOT(masterTimerData()));
   air_master_timer->start(MASTER_TIMER_INTERVAL);
 
@@ -269,6 +266,10 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   rdairplay_conf->setExitCode(RDAirPlayConf::ExitDirty);
   air_clear_filter=rdairplay_conf->clearFilter();
   air_bar_action=rdairplay_conf->barAction();
+  air_op_mode_style=rdairplay_conf->opModeStyle();
+  for(int i=0;i<RDAIRPLAY_LOG_QUANTITY;i++) {
+    air_op_mode[i]=RDAirPlayConf::Previous;
+  }
   air_editor_cmd=rdstation_conf->editorPath();
   mainmap=new QPixmap(rdairplay_conf->skinPath());
   if(mainmap->isNull()||(mainmap->width()<1024)||(mainmap->height()<738)) {
@@ -324,14 +325,14 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // CAE Connection
   //
-  rdcae=new RDCae(rdstation_conf,air_config,parent,name);
-  rdcae->connectHost();
+  air_cae=new RDCae(rdstation_conf,air_config,parent);
+  air_cae->connectHost();
 
   //
   // Set Audio Assignments
   //
   air_segue_length=rdairplay_conf->segueLength()+1;
-  RDSetMixerPorts(air_config->stationName(),rdcae);
+  RDSetMixerPorts(air_config->stationName(),air_cae);
 
   //
   // RIPC Connection
@@ -362,13 +363,13 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Log Machines
   //
-  QSignalMapper *reload_mapper=new QSignalMapper(this,"reload_mapper");
+  QSignalMapper *reload_mapper=new QSignalMapper(this);
   connect(reload_mapper,SIGNAL(mapped(int)),this,SLOT(logReloadedData(int)));
-  QSignalMapper *rename_mapper=new QSignalMapper(this,"rename_mapper");
+  QSignalMapper *rename_mapper=new QSignalMapper(this);
   connect(rename_mapper,SIGNAL(mapped(int)),this,SLOT(logRenamedData(int)));
   QString default_svcname=rdairplay_conf->defaultSvc();
   for(int i=0;i<RDAIRPLAY_LOG_QUANTITY;i++) {
-    air_log[i]=new LogPlay(rdcae,i,air_nownext_socket,"",&air_plugin_hosts);
+    air_log[i]=new LogPlay(i,air_nownext_socket,"",&air_plugin_hosts);
     air_log[i]->setDefaultServiceName(default_svcname);
     air_log[i]->setNowCart(rdairplay_conf->logNowCart(i));
     air_log[i]->setNextCart(rdairplay_conf->logNextCart(i));
@@ -426,17 +427,14 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Cart Picker
   //
-  rdcart_dialog=new RDCartDialog(&air_add_filter,&air_add_group,
-				 &air_add_schedcode,
-				 air_cue_card,air_cue_port,0,0,
-				 rdcae,rdripc,rdstation_conf,rdsystem_conf,
-				 rdstation_conf->editorPath(),
-				 this,"rdcart_dialog");
+  rdcart_dialog=
+    new RDCartDialog(&air_add_filter,&air_add_group,&air_add_schedcode,
+		     air_cae,rdripc,rdstation_conf,rdsystem_conf,air_config,this);
 
   //
   // Wall Clock
   //
-  WallClock *clock=new WallClock(this,"wall_clock");
+  WallClock *clock=new WallClock(this);
   clock->
     setGeometry(10,5,clock->sizeHint().width(),clock->sizeHint().height());
   clock->setCheckSyncEnabled(rdairplay_conf->checkTimesync());
@@ -448,7 +446,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Post Counter
   //
-  air_post_counter=new PostCounter(this,"air_post_counter");
+  air_post_counter=new PostCounter(this);
   air_post_counter->setGeometry(220,5,air_post_counter->sizeHint().width(),
 				air_post_counter->sizeHint().height());
   air_post_counter->setPostPoint(QTime(),0,false,false);
@@ -461,13 +459,12 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Pie Counter
   //
-  air_pie_counter=new PieCounter(rdairplay_conf->pieCountLength(),
-				 this,"air_pie_counter");
+  air_pie_counter=new PieCounter(rdairplay_conf->pieCountLength(),this);
   air_pie_counter->setGeometry(426,5,air_pie_counter->sizeHint().width(),
 				air_pie_counter->sizeHint().height());
   air_pie_counter->setCountLength(rdairplay_conf->pieCountLength());
   air_pie_end=rdairplay_conf->pieEndPoint();
-  air_pie_counter->setOpMode(air_op_mode);
+  air_pie_counter->setOpMode(air_op_mode[0]);
   air_pie_counter->setFocusPolicy(QWidget::NoFocus);
   if(mainmap!=NULL) {
     pm=new QPixmap(1024,738);
@@ -486,7 +483,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Audio Meter
   //
-  air_stereo_meter=new RDStereoMeter(this,"air_stereo_meter");
+  air_stereo_meter=new RDStereoMeter(this);
   air_stereo_meter->setGeometry(50,70,air_stereo_meter->sizeHint().width(),
 				air_stereo_meter->sizeHint().height());
   air_stereo_meter->setMode(RDSegMeter::Peak);
@@ -498,7 +495,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Message Label
   //
-  air_message_label=new RDLabel(this,"air_message_label");
+  air_message_label=new RDLabel(this);
   air_message_label->setGeometry(sizeHint().width()-425,70,
 		MESSAGE_WIDGET_WIDTH,air_stereo_meter->sizeHint().height());
   air_message_label->setWordWrapEnabled(true);
@@ -511,7 +508,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Stop Counter
   //
-  air_stop_counter=new StopCounter(this,"air_stop_counter");
+  air_stop_counter=new StopCounter(this);
   air_stop_counter->setGeometry(600,5,air_stop_counter->sizeHint().width(),
 				air_stop_counter->sizeHint().height());
   air_stop_counter->setTime(QTime(0,0,0));
@@ -524,12 +521,13 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Mode Display/Button
   //
-  air_mode_display=new ModeDisplay(this,"air_mode_display");
+  air_mode_display=new ModeDisplay(this);
   air_mode_display->
     setGeometry(sizeHint().width()-air_mode_display->sizeHint().width()-10,
 		5,air_mode_display->sizeHint().width(),
 		air_mode_display->sizeHint().height());
   air_mode_display->setFocusPolicy(QWidget::NoFocus);
+  air_mode_display->setOpModeStyle(air_op_mode_style);
   connect(air_mode_display,SIGNAL(clicked()),this,SLOT(modeButtonData()));
 
   //
@@ -556,7 +554,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Add Button
   //
-  air_add_button=new RDPushButton(this,"air_add_button");
+  air_add_button=new RDPushButton(this);
   air_add_button->setGeometry(10,sizeHint().height()-65,80,60);
   air_add_button->setFont(button_font);
   air_add_button->setText(tr("ADD"));
@@ -566,7 +564,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Delete Button
   //
-  air_delete_button=new RDPushButton(this,"air_delete_button");
+  air_delete_button=new RDPushButton(this);
   air_delete_button->setGeometry(100,sizeHint().height()-65,80,60);
   air_delete_button->setFont(button_font);
   air_delete_button->setText(tr("DEL"));
@@ -577,7 +575,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Move Button
   //
-  air_move_button=new RDPushButton(this,"air_move_button");
+  air_move_button=new RDPushButton(this);
   air_move_button->setGeometry(190,sizeHint().height()-65,80,60);
   air_move_button->setFont(button_font);
   air_move_button->setText(tr("MOVE"));
@@ -588,7 +586,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Copy Button
   //
-  air_copy_button=new RDPushButton(this,"air_copy_button");
+  air_copy_button=new RDPushButton(this);
   air_copy_button->setGeometry(280,sizeHint().height()-65,80,60);
   air_copy_button->setFont(button_font);
   air_copy_button->setText(tr("COPY"));
@@ -599,7 +597,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Refresh Indicator
   //
-  air_refresh_label=new RDLabel(this,"air_refresh_label");
+  air_refresh_label=new RDLabel(this);
   air_refresh_label->setGeometry(390,sizeHint().height()-65,120,60);
   air_refresh_label->setFont(button_font);
   QPalette p=palette();
@@ -618,7 +616,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Meter Timer
   //
-  timer=new QTimer(this,"meter_timer");
+  timer=new QTimer(this);
   connect(timer,SIGNAL(timeout()),this,SLOT(meterData()));
   timer->start(RD_METER_UPDATE_INTERVAL);
 
@@ -634,8 +632,8 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
 		       rdairplay_conf->panels(RDAirPlayConf::UserPanel),
 		       rdairplay_conf->flashPanel(),
 		       rdairplay_conf->buttonLabelTemplate(),false,
-		       rdevent_player,rdripc,rdcae,rdstation_conf,
-		       rdcart_dialog,this,"air_panel");
+		       rdevent_player,rdripc,air_cae,rdstation_conf,
+		       rdcart_dialog,this);
     air_panel->setLogfile(air_config->airplayLogname());
     air_panel->setGeometry(510,140,air_panel->sizeHint().width(),
 			 air_panel->sizeHint().height());
@@ -754,25 +752,26 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   air_pause_enabled=rdairplay_conf->pauseEnabled();
   for(int i=0;i<RDAIRPLAY_LOG_QUANTITY;i++) {
-    air_log_list[i]=new ListLog(air_log[i],i,air_pause_enabled,
-				this,"air_log_list");
+    air_log_list[i]=new ListLog(air_log[i],air_cae,i,air_pause_enabled,this);
     air_log_list[i]->setGeometry(510,140,air_log_list[i]->sizeHint().width(),
 			      air_log_list[i]->sizeHint().height());
     air_log_list[i]->hide();
     connect(air_log_list[i],SIGNAL(selectClicked(int,int,RDLogLine::Status)),
 	    this,SLOT(selectClickedData(int,int,RDLogLine::Status)));
+    connect(air_log_list[i],SIGNAL(cartDropped(int,int,RDLogLine *)),
+	    this,SLOT(cartDroppedData(int,int,RDLogLine *)));
   }
 
   //
-  // Full Log Button
+  // Full Log Buttons
   //
-  QSignalMapper *mapper=new QSignalMapper(this,"log_mapper");
+  QSignalMapper *mapper=new QSignalMapper(this);
   connect(mapper,SIGNAL(mapped(int)),this,SLOT(fullLogButtonData(int)));
   for(int i=0;i<RDAIRPLAY_LOG_QUANTITY;i++) {
     air_log_button[i]=new QPushButton(this);
-    air_log_button[i]->setGeometry(610+i*137,sizeHint().height()-65,127,60);
+    air_log_button[i]->setGeometry(647+i*123,sizeHint().height()-65,118,60);
     air_log_button[i]->setFont(button_font);
- air_log_button[i]->setFocusPolicy(QWidget::NoFocus);
+    air_log_button[i]->setFocusPolicy(QWidget::NoFocus);
     mapper->setMapping(air_log_button[i],i);
     connect(air_log_button[i],SIGNAL(clicked()),mapper,SLOT(map()));
   }
@@ -786,15 +785,24 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
     air_log_button[2]->hide();
   }
 
+  //
+  // Empty Cart
+  //
+  air_empty_cart=new RDEmptyCart(this);
+  air_empty_cart->setGeometry(520,sizeHint().height()-51,32,32);
+  if(!rdstation_conf->enableDragdrop()) {
+    air_empty_cart->hide();
+  }
+
   //
   // SoundPanel Button
   //
-  air_panel_button=new QPushButton(this,"air_panel_button");
-  air_panel_button->setGeometry(520,sizeHint().height()-65,80,60);
+  air_panel_button=new QPushButton(this);
+  air_panel_button->setGeometry(562,sizeHint().height()-65,80,60);
   air_panel_button->setFont(button_font);
   air_panel_button->setText(tr("Sound\nPanel"));
   air_panel_button->setPalette(active_color);
- air_panel_button->setFocusPolicy(QWidget::NoFocus);
+  air_panel_button->setFocusPolicy(QWidget::NoFocus);
   connect(air_panel_button,SIGNAL(clicked()),this,SLOT(panelButtonData()));
   if (rdairplay_conf->panels(RDAirPlayConf::StationPanel) || 
       rdairplay_conf->panels(RDAirPlayConf::UserPanel)){
@@ -809,8 +817,8 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Button Log
   //
-  air_button_list=new ButtonLog(air_log[0],0,air_pause_enabled,
-				this,"air_button_list");
+  air_button_list=new ButtonLog(air_log[0],air_cae,0,rdairplay_conf,
+				air_pause_enabled,this);
   air_button_list->setGeometry(10,140,air_button_list->sizeHint().width(),
 			       air_button_list->sizeHint().height());
   if(mainmap!=NULL) {
@@ -824,27 +832,36 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   }
   connect(air_button_list,SIGNAL(selectClicked(int,int,RDLogLine::Status)),
 	  this,SLOT(selectClickedData(int,int,RDLogLine::Status)));
+  connect(air_button_list,SIGNAL(cartDropped(int,int,RDLogLine *)),
+	  this,SLOT(cartDroppedData(int,int,RDLogLine *)));
 
   //
   // Set Startup Mode
   //
-  switch(rdairplay_conf->startMode()) {
+  for(int i=0;i<RDAIRPLAY_LOG_QUANTITY;i++) {
+    switch(rdairplay_conf->logStartMode(i)) {
       case RDAirPlayConf::Manual:
-	SetManualMode();
+	SetManualMode(i);
 	break;
 	
       case RDAirPlayConf::LiveAssist:
-	SetLiveAssistMode();
+	SetLiveAssistMode(i);
 	break;
 	
       case RDAirPlayConf::Auto:
-	SetAutoMode();
+	SetAutoMode(i);
 	break;
 	
       case RDAirPlayConf::Previous:
-	SetMode(rdairplay_conf->opMode());
+	if(air_op_mode_style==RDAirPlayConf::Unified) {
+	  SetMode(i,rdairplay_conf->opMode(0));
+	}
+	else {
+	  SetMode(i,rdairplay_conf->opMode(i));
+	}
 	break;
-  }	
+    }
+  }
 
   //
   // Load Plugins
@@ -877,11 +894,10 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
 
   // Create the HotKeyList object
   //
-  rdkeylist = new RDHotKeyList();
-  rdhotkeys = new RDHotkeys(RDEscapeString(air_config->stationName()),
-		  "airplay");
-  AltKeyHit = false;
-  CtrlKeyHit = false;
+  rdkeylist=new RDHotKeyList();
+  rdhotkeys=new RDHotkeys(air_config->stationName(),"rdairplay");
+  AltKeyHit=false;
+  CtrlKeyHit=false;
 
   //
   // Set Signal Handlers
@@ -1559,17 +1575,27 @@ void MainWidget::panelButtonData()
 
 void MainWidget::modeButtonData()
 {
-  switch(air_op_mode) {
+  int mach=-1;
+  switch(air_op_mode_style) {
+  case RDAirPlayConf::Unified:
+    mach=-1;
+    break;
+
+  case RDAirPlayConf::Independent:
+    mach=0;
+    break;
+  }
+  switch(air_op_mode[0]) {
       case RDAirPlayConf::Manual:
-	SetMode(RDAirPlayConf::LiveAssist);
+	SetMode(mach,RDAirPlayConf::LiveAssist);
 	break;
 
       case RDAirPlayConf::LiveAssist:
-	SetMode(RDAirPlayConf::Auto);
+	SetMode(mach,RDAirPlayConf::Auto);
 	break;
 
       case RDAirPlayConf::Auto:
-	SetMode(RDAirPlayConf::Manual);
+	SetMode(mach,RDAirPlayConf::Manual);
 	break;
 
       default:
@@ -1740,6 +1766,30 @@ void MainWidget::selectClickedData(unsigned cartnum,int row,int col)
 }
 
 
+void MainWidget::cartDroppedData(int id,int line,RDLogLine *ll)
+{
+  if(ll->cartNumber()==0) {
+    air_log[id]->remove(line,1);
+  }
+  else {
+    if(line<0) {
+      air_log[id]->
+	insert(air_log[id]->size(),ll->cartNumber(),RDLogLine::Play);
+      air_log[id]->logLine(air_log[id]->size()-1)->
+	setTransType(rdairplay_conf->defaultTransType());
+      air_log_list[id]->refresh(air_log[id]->size()-1);
+    }
+    else {
+      air_log[id]->
+	insert(line,ll->cartNumber(),air_log[id]->nextTransType(line));
+      air_log[id]->logLine(line)->
+	setTransType(rdairplay_conf->defaultTransType());
+      air_log_list[id]->refresh(line);
+    }
+  }
+}
+
+
 void MainWidget::meterData()
 {
 #ifdef SHOW_METER_SLOTS
@@ -1750,7 +1800,7 @@ void MainWidget::meterData()
 
   for(int i=0;i<AIR_TOTAL_PORTS;i++) {
     if(FirstPort(i)) {
-      rdcae->outputMeterUpdate(air_meter_card[i],air_meter_port[i],level);
+      air_cae->outputMeterUpdate(air_meter_card[i],air_meter_port[i],level);
       for(int j=0;j<2;j++) {
 	ratio[j]+=pow(10.0,((double)level[j])/1000.0);
       }
@@ -1817,7 +1867,7 @@ void MainWidget::transportChangedData()
     }
 
     logline=air_log[0]->logLine(line);
-    switch(air_op_mode) {
+    switch(air_op_mode[0]) {
 	case RDAirPlayConf::Manual:
 	case RDAirPlayConf::LiveAssist:
 	  pie_end=RDAirPlayConf::CartEnd;
@@ -1918,7 +1968,11 @@ void MainWidget::refreshStatusChangedData(bool active)
     }
     air_refresh_label->setText("");
   }
-  qApp->processEvents();
+  //
+  // FIXME: Disabled in 2.10.3caefix05 due to segfault problems.
+  //        Do we really need this?
+  //
+  //  qApp->processEvents();
 }
 
 
@@ -2184,22 +2238,28 @@ void MainWidget::SetCaption()
 }
 
 
-void MainWidget::SetMode(RDAirPlayConf::OpMode mode)
+void MainWidget::SetMode(int mach,RDAirPlayConf::OpMode mode)
 {
-  if(air_op_mode==mode) {
+  if(mach<0) {
+    for(int i=0;i<RDAIRPLAY_LOG_QUANTITY;i++) {
+      SetMode(i,mode);
+    }
+    return;
+  }
+  if(air_op_mode[mach]==mode) {
     return;
   }
   switch(mode) {
       case RDAirPlayConf::Manual:
-	SetManualMode();
+	SetManualMode(mach);
 	break;
 
       case RDAirPlayConf::LiveAssist:
-	SetLiveAssistMode();
+	SetLiveAssistMode(mach);
 	break;
 
       case RDAirPlayConf::Auto:
-	SetAutoMode();
+	SetAutoMode(mach);
 	break;
 
       default:
@@ -2208,51 +2268,78 @@ void MainWidget::SetMode(RDAirPlayConf::OpMode mode)
 }
 
 
-void MainWidget::SetManualMode()
+void MainWidget::SetManualMode(int mach)
 {
-  air_mode_display->setMode(RDAirPlayConf::Manual);
-  air_op_mode=RDAirPlayConf::Manual;
-  air_pie_counter->setOpMode(RDAirPlayConf::Manual);
-  rdairplay_conf->setOpMode(RDAirPlayConf::Manual);
-  for(int i=0;i<RDAIRPLAY_LOG_QUANTITY;i++) {
-    air_log[i]->setMode(RDAirPlayConf::Manual);
-    air_log_list[i]->setOpMode(RDAirPlayConf::Manual);
+  if(mach<0) {
+    for(int i=0;i<RDAIRPLAY_LOG_QUANTITY;i++) {
+      SetManualMode(i);
+    }
+    return;
   }
-  air_button_list->setOpMode(RDAirPlayConf::Manual);
-  air_post_counter->setDisabled(true);
-  LogLine(RDConfig::LogInfo,"mode set to MANUAL");
+  if(mach==0) {
+    air_pie_counter->setOpMode(RDAirPlayConf::Manual);
+  }
+  air_mode_display->setOpMode(mach,RDAirPlayConf::Manual);
+  air_op_mode[mach]=RDAirPlayConf::Manual;
+  rdairplay_conf->setOpMode(mach,RDAirPlayConf::Manual);
+  air_log[mach]->setOpMode(RDAirPlayConf::Manual);
+  air_log_list[mach]->setOpMode(RDAirPlayConf::Manual);
+  if(mach==0) {
+    air_button_list->setOpMode(RDAirPlayConf::Manual);
+    air_post_counter->setDisabled(true);
+  }
+  LogLine(RDConfig::LogInfo,
+	  QString().sprintf("log machine %d mode set to MANUAL",mach+1));
 }
 
 
-void MainWidget::SetAutoMode()
+void MainWidget::SetAutoMode(int mach)
 {
-  air_mode_display->setMode(RDAirPlayConf::Auto);
-  air_op_mode=RDAirPlayConf::Auto;
-  air_pie_counter->setOpMode(RDAirPlayConf::Auto);
-  rdairplay_conf->setOpMode(RDAirPlayConf::Auto);
-  for(int i=0;i<RDAIRPLAY_LOG_QUANTITY;i++) {
-    air_log[i]->setMode(RDAirPlayConf::Auto);
-    air_log_list[i]->setOpMode(RDAirPlayConf::Auto);
+  if(mach<0) {
+    for(int i=0;i<RDAIRPLAY_LOG_QUANTITY;i++) {
+      SetAutoMode(i);
+    }
+    return;
   }
-  air_button_list->setOpMode(RDAirPlayConf::Auto);
-  air_post_counter->setEnabled(true);
-  LogLine(RDConfig::LogInfo,"mode set to AUTO");
+  if(mach==0) {
+    air_pie_counter->setOpMode(RDAirPlayConf::Auto);
+  }
+  air_mode_display->setOpMode(mach,RDAirPlayConf::Auto);
+  air_op_mode[mach]=RDAirPlayConf::Auto;
+  rdairplay_conf->setOpMode(mach,RDAirPlayConf::Auto);
+  air_log[mach]->setOpMode(RDAirPlayConf::Auto);
+  air_log_list[mach]->setOpMode(RDAirPlayConf::Auto);
+  if(mach==0) {
+    air_button_list->setOpMode(RDAirPlayConf::Auto);
+    air_post_counter->setEnabled(true);
+  }
+  LogLine(RDConfig::LogInfo,
+	  QString().sprintf("log machine %d mode set to AUTO",mach+1));
 }
 
 
-void MainWidget::SetLiveAssistMode()
+void MainWidget::SetLiveAssistMode(int mach)
 {
-  air_mode_display->setMode(RDAirPlayConf::LiveAssist);
-  air_op_mode=RDAirPlayConf::LiveAssist;
-  air_pie_counter->setOpMode(RDAirPlayConf::LiveAssist);
-  rdairplay_conf->setOpMode(RDAirPlayConf::LiveAssist);
-  for(int i=0;i<RDAIRPLAY_LOG_QUANTITY;i++) {
-    air_log[i]->setMode(RDAirPlayConf::LiveAssist);
-    air_log_list[i]->setOpMode(RDAirPlayConf::LiveAssist);
+  if(mach<0) {
+    for(int i=0;i<RDAIRPLAY_LOG_QUANTITY;i++) {
+      SetLiveAssistMode(i);
+    }
+    return;
   }
-  air_button_list->setOpMode(RDAirPlayConf::LiveAssist); 
-  air_post_counter->setDisabled(true);
-  LogLine(RDConfig::LogInfo,"mode set to LIVE ASSIST");
+  if(mach==0) {
+    air_pie_counter->setOpMode(RDAirPlayConf::LiveAssist);
+  }
+  air_mode_display->setOpMode(mach,RDAirPlayConf::LiveAssist);
+  air_op_mode[mach]=RDAirPlayConf::LiveAssist;
+  rdairplay_conf->setOpMode(mach,RDAirPlayConf::LiveAssist);
+  air_log[mach]->setOpMode(RDAirPlayConf::LiveAssist);
+  air_log_list[mach]->setOpMode(RDAirPlayConf::LiveAssist);
+  if(mach==0) {
+    air_button_list->setOpMode(RDAirPlayConf::LiveAssist); 
+    air_post_counter->setDisabled(true);
+  }
+  LogLine(RDConfig::LogInfo,
+	  QString().sprintf("log machine %d mode set to LIVE ASSIST",mach+1));
 }
 
 
@@ -2463,7 +2550,7 @@ int main(int argc,char *argv[])
   //
   // Start Event Loop
   //
-  MainWidget *w=new MainWidget(NULL,"main");
+  MainWidget *w=new MainWidget();
   a.setMainWidget(w);
   w->setGeometry(QRect(QPoint(0,0),w->sizeHint()));
   w->show();
