@@ -3,660 +3,698 @@
     <name>EditEvent</name>
     <message>
         <source>Edit Event</source>
-        <translation type="unfinished"></translation>
+        <translation>Modifier un événement</translation>
     </message>
     <message>
         <source>Start at:</source>
-        <translation type="unfinished"></translation>
+        <translation>Lancer à:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
-        <translation type="unfinished"></translation>
+        <translation>Action si le précédent n&apos;est pas fini</translation>
     </message>
     <message>
         <source>Start Immediately</source>
-        <translation type="unfinished"></translation>
+        <translation>Lancer immédiatement</translation>
     </message>
     <message>
         <source>Make Next</source>
-        <translation type="unfinished"></translation>
+        <translation>Utiliser ensuite</translation>
     </message>
     <message>
         <source>Wait up to</source>
-        <translation type="unfinished"></translation>
+        <translation>Attendre</translation>
     </message>
     <message>
         <source>Play</source>
-        <translation type="unfinished"></translation>
+        <translation>Lancer</translation>
     </message>
     <message>
         <source>Segue</source>
-        <translation type="unfinished"></translation>
+        <translation>Enchainer</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation type="unfinished"></translation>
+        <translation>Stopper</translation>
     </message>
     <message>
         <source>Start Transition Type:</source>
-        <translation type="unfinished"></translation>
+        <translation>Transition au début :</translation>
     </message>
     <message>
         <source>No Fade at Segue Out</source>
-        <translation type="unfinished"></translation>
+        <translation>Pas de fondu à l&apos;enchaînement</translation>
+    </message>
+    <message>
+        <source>&amp;Audition</source>
+        <translation type="obsolete">&amp;Ecouter</translation>
+    </message>
+    <message>
+        <source>&amp;Pause</source>
+        <translation type="obsolete">&amp;Pause</translation>
+    </message>
+    <message>
+        <source>&amp;Stop</source>
+        <translation type="obsolete">&amp;Stopper</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation type="obsolete">Début</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Transition If Previous Cart Ends Before</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Duplicate Start Time</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>An event is already scheduled with this start time!</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Annuler</translation>
     </message>
     <message>
         <source>Edit Marker</source>
-        <translation type="unfinished"></translation>
+        <translation>Modifier une marque</translation>
     </message>
     <message>
         <source>Edit Track</source>
-        <translation type="unfinished"></translation>
+        <translation>Modifier un Voice Track</translation>
     </message>
     <message>
         <source>Edit Log Track</source>
-        <translation type="unfinished"></translation>
+        <translation>Modifier un Log Track</translation>
+    </message>
+    <message>
+        <source>Transition If Previous Cart Ends Before</source>
+        <translation>Transition si le précédent finit avant</translation>
+    </message>
+    <message>
+        <source>End</source>
+        <translation type="obsolete">Fin</translation>
+    </message>
+    <message>
+        <source>Cart Notes</source>
+        <translation>Notes du Cart</translation>
+    </message>
+    <message>
+        <source>Duplicate Start Time</source>
+        <translation>Même heure de lancement</translation>
+    </message>
+    <message>
+        <source>An event is already scheduled with this start time!</source>
+        <translation>Un événement est déjà planifié à cette heure!</translation>
     </message>
 </context>
 <context>
     <name>HourSelector</name>
     <message>
         <source>12a</source>
-        <translation type="unfinished"></translation>
+        <translation>00</translation>
     </message>
     <message>
         <source>1a</source>
-        <translation type="unfinished"></translation>
+        <translation>01</translation>
     </message>
     <message>
         <source>2a</source>
-        <translation type="unfinished"></translation>
+        <translation>02</translation>
     </message>
     <message>
         <source>3a</source>
-        <translation type="unfinished"></translation>
+        <translation>03</translation>
     </message>
     <message>
         <source>4a</source>
-        <translation type="unfinished"></translation>
+        <translation>04</translation>
     </message>
     <message>
         <source>5a</source>
-        <translation type="unfinished"></translation>
+        <translation>05</translation>
     </message>
     <message>
         <source>6a</source>
-        <translation type="unfinished"></translation>
+        <translation>06</translation>
     </message>
     <message>
         <source>7a</source>
-        <translation type="unfinished"></translation>
+        <translation>07</translation>
     </message>
     <message>
         <source>8a</source>
-        <translation type="unfinished"></translation>
+        <translation>08</translation>
     </message>
     <message>
         <source>9a</source>
-        <translation type="unfinished"></translation>
+        <translation>09</translation>
     </message>
     <message>
         <source>10a</source>
-        <translation type="unfinished"></translation>
+        <translation>10</translation>
     </message>
     <message>
         <source>11a</source>
-        <translation type="unfinished"></translation>
+        <translation>11</translation>
     </message>
     <message>
         <source>12p</source>
-        <translation type="unfinished"></translation>
+        <translation>12</translation>
     </message>
     <message>
         <source>1p</source>
-        <translation type="unfinished"></translation>
+        <translation>13</translation>
     </message>
     <message>
         <source>2p</source>
-        <translation type="unfinished"></translation>
+        <translation>14</translation>
     </message>
     <message>
         <source>3p</source>
-        <translation type="unfinished"></translation>
+        <translation>15</translation>
     </message>
     <message>
         <source>4p</source>
-        <translation type="unfinished"></translation>
+        <translation>16</translation>
     </message>
     <message>
         <source>5p</source>
-        <translation type="unfinished"></translation>
+        <translation>17</translation>
     </message>
     <message>
         <source>6p</source>
-        <translation type="unfinished"></translation>
+        <translation>18</translation>
     </message>
     <message>
         <source>7p</source>
-        <translation type="unfinished"></translation>
+        <translation>19</translation>
     </message>
     <message>
         <source>8p</source>
-        <translation type="unfinished"></translation>
+        <translation>20</translation>
     </message>
     <message>
         <source>9p</source>
-        <translation type="unfinished"></translation>
+        <translation>21</translation>
     </message>
     <message>
         <source>10p</source>
-        <translation type="unfinished"></translation>
+        <translation>22</translation>
     </message>
     <message>
         <source>11p</source>
-        <translation type="unfinished"></translation>
+        <translation>23</translation>
     </message>
 </context>
 <context>
     <name>ListLog</name>
     <message>
         <source>EST TIME</source>
-        <translation type="unfinished"></translation>
+        <translation>HORAIRE EST</translation>
     </message>
     <message>
         <source>LEN</source>
-        <translation type="unfinished"></translation>
+        <translation>DUREE</translation>
     </message>
     <message>
         <source>TRANS</source>
-        <translation type="unfinished"></translation>
+        <translation>TRANS</translation>
     </message>
     <message>
         <source>CART</source>
-        <translation type="unfinished"></translation>
+        <translation>CART</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation type="unfinished"></translation>
+        <translation>TITRE</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation type="unfinished"></translation>
+        <translation>ARTISTE</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation type="unfinished"></translation>
+        <translation>GROUPE</translation>
     </message>
     <message>
         <source>TIME</source>
-        <translation type="unfinished"></translation>
+        <translation>HORAIRE</translation>
     </message>
     <message>
         <source>CLIENT</source>
-        <translation type="unfinished"></translation>
+        <translation>CLIENT</translation>
     </message>
     <message>
         <source>AGENCY</source>
-        <translation type="unfinished"></translation>
+        <translation>AGENCE</translation>
     </message>
     <message>
         <source>LABEL</source>
-        <translation type="unfinished"></translation>
+        <translation>LABEL</translation>
     </message>
     <message>
         <source>LINE ID</source>
-        <translation type="unfinished"></translation>
+        <translation>LIGNE ID</translation>
     </message>
     <message>
         <source>COUNT</source>
-        <translation type="unfinished"></translation>
+        <translation>NUMERO</translation>
     </message>
     <message>
         <source>STATUS</source>
-        <translation type="unfinished"></translation>
+        <translation>STATUT</translation>
     </message>
     <message>
         <source>Select</source>
-        <translation type="unfinished"></translation>
+        <translation>Sélectionner</translation>
     </message>
     <message>
         <source>Make
 Next</source>
-        <translation type="unfinished"></translation>
+        <translation>Utiliser
+Ensuite</translation>
     </message>
     <message>
         <source>Modify</source>
-        <translation type="unfinished"></translation>
+        <translation>Modifier</translation>
     </message>
     <message>
         <source>Scroll</source>
-        <translation type="unfinished"></translation>
+        <translation>Dérouler</translation>
     </message>
     <message>
         <source>Refresh
 Log</source>
-        <translation type="unfinished"></translation>
+        <translation>Rafraichir
+le Log</translation>
     </message>
     <message>
         <source>Select
 Log</source>
-        <translation type="unfinished"></translation>
+        <translation>Choisir
+un Log</translation>
     </message>
     <message>
         <source>Log Exists</source>
-        <translation type="unfinished"></translation>
+        <translation>Ce Log existe</translation>
     </message>
     <message>
         <source>Log Already Exists!</source>
-        <translation type="unfinished"></translation>
+        <translation>Ce Log existe déjà !</translation>
     </message>
     <message>
         <source>--- end of log ---</source>
-        <translation type="unfinished"></translation>
+        <translation>-- fin du log --</translation>
     </message>
     <message>
         <source>PLAY</source>
-        <translation type="unfinished"></translation>
+        <translation>LANCER</translation>
     </message>
     <message>
         <source>STOP</source>
-        <translation type="unfinished"></translation>
+        <translation>STOPPER</translation>
     </message>
     <message>
         <source>SEGUE</source>
-        <translation type="unfinished"></translation>
+        <translation>ENCHAINER</translation>
     </message>
     <message>
         <source>MARKER</source>
-        <translation type="unfinished"></translation>
+        <translation>MARQUE</translation>
     </message>
     <message>
         <source>TRACK</source>
-        <translation type="unfinished"></translation>
+        <translation>TRACK</translation>
     </message>
     <message>
         <source>LINK</source>
-        <translation type="unfinished"></translation>
+        <translation>LIEN</translation>
     </message>
     <message>
         <source>[music import]</source>
-        <translation type="unfinished"></translation>
+        <translation>[import musique]</translation>
     </message>
     <message>
         <source>[traffic import]</source>
-        <translation type="unfinished"></translation>
+        <translation>[import pub]</translation>
     </message>
     <message>
         <source>CHAIN TO</source>
-        <translation type="unfinished"></translation>
+        <translation>LIER A</translation>
     </message>
     <message>
         <source>[CART NOT FOUND]</source>
-        <translation type="unfinished"></translation>
+        <translation>[CART INCONNU]</translation>
     </message>
     <message>
         <source>[NO VALID CUT AVAILABLE]</source>
-        <translation type="unfinished"></translation>
+        <translation>[PAS DE CUT DISPONIBLE]</translation>
     </message>
     <message>
         <source>[NO AUDIO AVAILABLE]</source>
-        <translation type="unfinished"></translation>
+        <translation>[PAS DE SON DISPONIBLE]</translation>
     </message>
     <message>
         <source>T</source>
-        <translation type="unfinished"></translation>
+        <translation>T</translation>
     </message>
     <message>
         <source>Pause</source>
-        <translation type="unfinished"></translation>
+        <translation>Pause</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation type="unfinished"></translation>
+        <translation>Stop</translation>
     </message>
     <message>
         <source>Start</source>
-        <translation type="unfinished"></translation>
+        <translation>Lancer</translation>
     </message>
     <message>
         <source>Run Length</source>
-        <translation type="unfinished"></translation>
+        <translation>Durées</translation>
     </message>
     <message>
         <source>Next Stop:</source>
-        <translation type="unfinished"></translation>
+        <translation>Avt Arrêt:</translation>
     </message>
     <message>
         <source>Log End:</source>
-        <translation type="unfinished"></translation>
+        <translation>Fin du Log:</translation>
     </message>
     <message>
         <source>Selected:</source>
-        <translation type="unfinished"></translation>
+        <translation>Sélection:</translation>
     </message>
     <message>
         <source>Audition
 Head</source>
-        <translation type="unfinished"></translation>
+        <translation>Ecouter
+le Début</translation>
     </message>
     <message>
         <source>Audition
 Tail</source>
-        <translation type="unfinished"></translation>
+        <translation>Ecouter
+la Fin</translation>
     </message>
     <message>
         <source>ALBUM</source>
-        <translation type="unfinished"></translation>
+        <translation>ALBUM</translation>
     </message>
 </context>
 <context>
     <name>ListLogs</name>
     <message>
         <source>Select a Log</source>
-        <translation type="unfinished"></translation>
+        <translation>Sélectionner un Log</translation>
     </message>
     <message>
         <source>NAME</source>
-        <translation type="unfinished"></translation>
+        <translation>NOM</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation type="unfinished"></translation>
+        <translation>DESCRIPTION</translation>
     </message>
     <message>
         <source>SERVICE</source>
-        <translation type="unfinished"></translation>
+        <translation>SERVICE</translation>
     </message>
     <message>
         <source>Load</source>
-        <translation type="unfinished"></translation>
+        <translation>Charger</translation>
     </message>
     <message>
         <source>Unload</source>
-        <translation type="unfinished"></translation>
+        <translation>Vider</translation>
     </message>
     <message>
         <source>Save</source>
-        <translation type="unfinished"></translation>
+        <translation>Sauver</translation>
     </message>
     <message>
         <source>Save &amp;As</source>
-        <translation type="unfinished"></translation>
+        <translation>S&amp;auver Sous</translation>
     </message>
     <message>
         <source>Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation>Annuler</translation>
     </message>
     <message>
         <source>Rename Log</source>
-        <translation type="unfinished"></translation>
+        <translation>Renommer le Log</translation>
     </message>
 </context>
 <context>
     <name>LogLineBox</name>
     <message>
         <source>STOP</source>
-        <translation type="unfinished"></translation>
+        <translation>STOPPER</translation>
     </message>
     <message>
         <source>PLAY</source>
-        <translation type="unfinished"></translation>
+        <translation>LANCER</translation>
     </message>
     <message>
         <source>SEGUE</source>
-        <translation type="unfinished"></translation>
+        <translation>ENCHAINER</translation>
     </message>
     <message>
         <source>[CART NOT FOUND]</source>
-        <translation type="unfinished"></translation>
+        <translation>[CART INCONNU]</translation>
     </message>
     <message>
         <source>[NO AUDIO AVAILABLE]</source>
-        <translation type="unfinished"></translation>
+        <translation>[PAS DE SON DISPONIBLE]</translation>
     </message>
     <message>
         <source>[NO VALID CUT AVAILABLE]</source>
-        <translation type="unfinished"></translation>
+        <translation>[PAS DE CUT DISPONIBLE]</translation>
     </message>
     <message>
         <source>MARKER</source>
-        <translation type="unfinished"></translation>
+        <translation>MARQUE</translation>
     </message>
     <message>
         <source>TRACK</source>
-        <translation type="unfinished"></translation>
+        <translation>TRACK</translation>
     </message>
     <message>
         <source>LINK</source>
-        <translation type="unfinished"></translation>
+        <translation>LIEN</translation>
     </message>
     <message>
         <source>[music import]</source>
-        <translation type="unfinished"></translation>
+        <translation>[import musique]</translation>
     </message>
     <message>
         <source>[traffic import]</source>
-        <translation type="unfinished"></translation>
+        <translation>[import pub]</translation>
     </message>
     <message>
         <source>CHAIN</source>
-        <translation type="unfinished"></translation>
+        <translation>LIER A</translation>
     </message>
     <message>
         <source>T</source>
-        <translation type="unfinished"></translation>
+        <translation>T</translation>
     </message>
 </context>
 <context>
     <name>MainWidget</name>
     <message>
         <source>RDAirPlay</source>
-        <translation type="unfinished"></translation>
+        <translation>RDAirPlay</translation>
     </message>
     <message>
         <source>Multiple instances not allowed!</source>
-        <translation type="unfinished"></translation>
+        <translation>Plusieurs instances ne sont pas autorisées !</translation>
+    </message>
+    <message>
+        <source>RDAirPlay - Host:</source>
+        <translation type="obsolete">RDAirPlay - Station :</translation>
     </message>
     <message>
         <source>Database Error</source>
-        <translation type="unfinished"></translation>
+        <translation>Erreur de base de données</translation>
     </message>
     <message>
         <source>ADD</source>
-        <translation type="unfinished"></translation>
+        <translation>Ajouter</translation>
     </message>
     <message>
         <source>DEL</source>
-        <translation type="unfinished"></translation>
+        <translation>Suppr</translation>
     </message>
     <message>
         <source>MOVE</source>
-        <translation type="unfinished"></translation>
+        <translation>Déplacer</translation>
     </message>
     <message>
         <source>COPY</source>
-        <translation type="unfinished"></translation>
+        <translation>Copier</translation>
     </message>
     <message>
         <source>Main Log
 [--]</source>
-        <translation type="unfinished"></translation>
+        <translation>Log Principal
+[--]</translation>
     </message>
     <message>
         <source>Aux 1 Log
 [--]</source>
-        <translation type="unfinished"></translation>
+        <translation>Log Aux 1
+[--]</translation>
     </message>
     <message>
         <source>Aux 2 Log
 [--]</source>
-        <translation type="unfinished"></translation>
+        <translation>Log Aux 2
+[--]</translation>
     </message>
     <message>
         <source>Sound
 Panel</source>
-        <translation type="unfinished"></translation>
+        <translation>Panneau
+de sons</translation>
     </message>
     <message>
         <source>Main Log</source>
-        <translation type="unfinished"></translation>
+        <translation>Log Principal</translation>
     </message>
     <message>
         <source>Aux 1 Log</source>
-        <translation type="unfinished"></translation>
+        <translation>Log Aux 1</translation>
     </message>
     <message>
         <source>Aux 2 Log</source>
-        <translation type="unfinished"></translation>
+        <translation>Log Aux 2</translation>
     </message>
     <message>
         <source>LOG
 REFRESHING</source>
-        <translation type="unfinished"></translation>
+        <translation>MISE A JOUR
+DU LOG</translation>
     </message>
     <message>
         <source>Exit RDAirPlay?</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>User:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Log:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Service:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Host</source>
-        <translation type="unfinished"></translation>
+        <translation>Quitter RDAirPlay ?</translation>
     </message>
     <message>
         <source>Host:</source>
-        <translation type="unfinished"></translation>
+        <translation>Station:</translation>
+    </message>
+    <message>
+        <source>Host</source>
+        <translation>Station</translation>
+    </message>
+    <message>
+        <source>User:</source>
+        <translation>Utilisateur:</translation>
+    </message>
+    <message>
+        <source>Log:</source>
+        <translation>Log:</translation>
+    </message>
+    <message>
+        <source>Service:</source>
+        <translation>Service:</translation>
     </message>
 </context>
 <context>
     <name>ModeDisplay</name>
+    <message>
+        <source>Operating Mode</source>
+        <translation>Mode opérationnel</translation>
+    </message>
     <message>
         <source>LiveAssist</source>
-        <translation type="unfinished"></translation>
+        <translation>Direct Assisté</translation>
     </message>
     <message>
         <source>Automatic</source>
-        <translation type="unfinished"></translation>
+        <translation>Automatique</translation>
     </message>
     <message>
         <source>Manual</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Operating Mode</source>
-        <translation type="unfinished"></translation>
+        <translation>Manuel</translation>
     </message>
     <message>
         <source>Aux1</source>
-        <translation type="unfinished"></translation>
+        <translation>Aux1</translation>
     </message>
     <message>
         <source>Aux2</source>
-        <translation type="unfinished"></translation>
+        <translation>Aux2</translation>
     </message>
 </context>
 <context>
     <name>PostCounter</name>
     <message>
         <source>Next Timed Start</source>
-        <translation type="unfinished"></translation>
+        <translation>Lancement planifié à</translation>
     </message>
     <message>
         <source>On Time</source>
-        <translation type="unfinished"></translation>
+        <translation>A l&apos;heure</translation>
     </message>
     <message>
         <source>Next Timed Start [--:--:--]</source>
-        <translation type="unfinished"></translation>
+        <translation>Lancement planifié à [--:--:--]</translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
         <source>START</source>
-        <translation type="unfinished"></translation>
+        <translation>LANCER</translation>
     </message>
     <message>
         <source>STOP</source>
-        <translation type="unfinished"></translation>
+        <translation>STOPPER</translation>
     </message>
     <message>
         <source>PAUSE</source>
-        <translation type="unfinished"></translation>
+        <translation>PAUSE</translation>
     </message>
     <message>
         <source>RESUME</source>
-        <translation type="unfinished"></translation>
+        <translation>RELANCER</translation>
     </message>
     <message>
         <source>WHERE?</source>
-        <translation type="unfinished"></translation>
+        <translation>OU?</translation>
     </message>
     <message>
         <source>DELETE?</source>
-        <translation type="unfinished"></translation>
+        <translation>SUPPR?</translation>
     </message>
     <message>
         <source>MOVE?</source>
-        <translation type="unfinished"></translation>
+        <translation>DEPLACER?</translation>
     </message>
     <message>
         <source>TO?</source>
-        <translation type="unfinished"></translation>
+        <translation>VERS?</translation>
     </message>
     <message>
         <source>COPY?</source>
-        <translation type="unfinished"></translation>
+        <translation>COPIE?</translation>
     </message>
     <message>
         <source>ERROR</source>
-        <translation type="unfinished"></translation>
+        <translation>ERREUR</translation>
     </message>
 </context>
 <context>
     <name>StopCounter</name>
     <message>
         <source>Next Stop [none]</source>
-        <translation type="unfinished"></translation>
+        <translation>Prochain Arrêt [aucun]</translation>
     </message>
     <message>
         <source>Next Stop</source>
-        <translation type="unfinished"></translation>
+        <translation>Prochain Arret</translation>
     </message>
     <message>
         <source>Stopped</source>
-        <translation type="unfinished"></translation>
+        <translation>Arrêté</translation>
     </message>
 </context>
 </TS>
