@@ -2,9 +2,7 @@
 //
 // Edit a Rivendell Voice Track Log Entry
 //
-//   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: edit_track.h,v 1.8 2010/07/29 19:32:37 cvs Exp $
+//   (C) Copyright 2002-2005,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -40,7 +38,7 @@ class EditTrack : public QDialog
 {
   Q_OBJECT
  public:
-  EditTrack(RDLogLine *,QWidget *parent=0,const char *name=0);
+  EditTrack(RDLogLine *,QWidget *parent=0);
   ~EditTrack();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
