@@ -2,9 +2,7 @@
 //
 // List Rivendell Log Clocks
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: list_clocks.cpp,v 1.28.8.2 2014/01/10 19:32:54 cvs Exp $
+//   (C) Copyright 2002-2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -39,9 +37,8 @@
 #include <globals.h>
 #include <rename_item.h>
 
-
-ListClocks::ListClocks(QString *clockname,QWidget *parent,const char *name)
-  : QDialog(parent,name,true)
+ListClocks::ListClocks(QString *clockname,QWidget *parent)
+  : QDialog(parent,"",true)
 {
   QStringList services_list;
   QString str1=tr("Log Clocks - User: ");
@@ -66,7 +63,7 @@ ListClocks::ListClocks(QString *clockname,QWidget *parent,const char *name)
   //
   // Event Filter
   //
-  edit_filter_box=new QComboBox(this,"edit_filter_box");
+  edit_filter_box=new QComboBox(this);
   edit_filter_label=new QLabel(edit_filter_box,tr("Filter:"),this);
   edit_filter_label->setFont(bold_font);
   edit_filter_label->setAlignment(AlignRight|AlignVCenter);
@@ -76,7 +73,7 @@ ListClocks::ListClocks(QString *clockname,QWidget *parent,const char *name)
   //
   // Clocks List
   //
-  edit_clocks_list=new QListView(this,"edit_clocks_list");
+  edit_clocks_list=new QListView(this);
   edit_clocks_list->setAllColumnsShowFocus(true);
   edit_clocks_list->setItemMargin(5);
   edit_clocks_list->addColumn(tr("Name"));
@@ -226,7 +223,7 @@ void ListClocks::addData()
   RDSqlQuery *q1;
   std::vector<QString> new_clocks;
 
-  AddClock *add_dialog=new AddClock(&clockname,this,"add_dialog");
+  AddClock *add_dialog=new AddClock(&clockname,this);
   if(add_dialog->exec()<0) {
     delete add_dialog;
     return;
@@ -250,8 +247,7 @@ void ListClocks::addData()
   sql=RDCreateClockTableSql(RDClock::tableName(clockname));
   q=new RDSqlQuery(sql);
   delete q;
-  EditClock *clock_dialog=new EditClock(clockname,true,&new_clocks,
-					this,"clock_dialog");
+  EditClock *clock_dialog=new EditClock(clockname,true,&new_clocks,this);
   if(clock_dialog->exec()<0) {
     clockname_esc=clockname;
     clockname_esc.replace(" ","_");
@@ -305,8 +301,7 @@ void ListClocks::editData()
   if(item==NULL) {
     return;
   }
-  EditClock *clock_dialog=
-    new EditClock(item->text(0),false,&new_clocks,this,"clock_dialog");
+  EditClock *clock_dialog=new EditClock(item->text(0),false,&new_clocks,this);
   if(clock_dialog->exec()<0) {
     delete clock_dialog;
     return;
@@ -363,8 +358,7 @@ void ListClocks::renameData()
     return;
   }
   QString new_name=item->text(0);
-  RenameItem *rename_dialog=
-    new RenameItem(&new_name,"CLOCKS",this,"event_dialog");
+  RenameItem *rename_dialog=new RenameItem(&new_name,"CLOCKS",this);
   if(rename_dialog->exec()<-1) {
     delete rename_dialog;
     return;
