@@ -186,6 +186,10 @@ Vil du lagra?</translation>
         <source>Remarks</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>&amp;Clone</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditEvent</name>
@@ -525,6 +529,10 @@ Vil du byta henne ut?</translation>
         <source>IMPORT</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>and code</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditEventLine</name>
@@ -597,6 +605,23 @@ ei anna hending som finst frå før.</translation>
         <source>Clear Hour</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Change
+&amp;All</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Clear Clocks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to update ALL clocks in the grid?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This operation cannot be undone!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditNote</name>
@@ -1264,7 +1289,11 @@ rapport</translation>
     </message>
     <message>
         <source>Report complete!</source>
-        <translation>Rapporten er ferdig!</translation>
+        <translation type="obsolete">Rapporten er ferdig!</translation>
+    </message>
+    <message>
+        <source>Report generated in</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
